@@ -22,24 +22,27 @@
 
 #include "pimsettingexporter_export.h"
 #include <QHash>
-#include <QDomDocument>
 #include "utils.h"
-
+class QXmlStreamWriter;
+class QXmlStreamReader;
 class PIMSETTINGEXPORTER_EXPORT TemplateSelection
 {
 public:
-    TemplateSelection(const QString &path = QString());
+    TemplateSelection();
     ~TemplateSelection();
 
     void createTemplate(const QHash<Utils::AppsType, Utils::importExportParameters> &stored);
 
-    QDomDocument document() const;
+    QHash<Utils::AppsType, Utils::importExportParameters> loadTemplate(const QString &path);
+
+    QString saveTemplate() const;
 
-    QHash<Utils::AppsType, Utils::importExportParameters> loadTemplate(const QDomDocument &doc = QDomDocument());
 private:
-    static Utils::StoredTypes loadStoredTypes(const QDomElement &element, int &numberOfStep);
-    void saveParameters(Utils::StoredTypes type, QDomElement &elem);
-    QDomDocument mDocument;
+    Utils::StoredTypes loadStoredTypes(int &numberOfStep);
+    void saveParameters(Utils::StoredTypes type);
+    QXmlStreamWriter *mStreamWriter;
+    QXmlStreamReader *mStreamReader;
+    QString mSaveTemplate;
 };
 
 #endif // TEMPLATESELECTION_H
