@@ -29,15 +29,15 @@ public:
     explicit ImportExportProgressIndicatorGui(QWidget *parentWidget, QObject *parent = nullptr);
     ~ImportExportProgressIndicatorGui();
 
-    void increaseProgressDialog() Q_DECL_OVERRIDE;
-    void createProgressDialog(const QString &title) Q_DECL_OVERRIDE;
+    void increaseProgressDialog() override;
+    void createProgressDialog(const QString &title) override;
 
-    void setProgressDialogLabel(const QString &text) Q_DECL_OVERRIDE;
-    bool wasCanceled() const Q_DECL_OVERRIDE;
-    int mergeConfigMessageBox(const QString &configName) const Q_DECL_OVERRIDE;
-    bool overwriteConfigMessageBox(const QString &configName) const Q_DECL_OVERRIDE;
-    bool overwriteDirectoryMessageBox(const QString &directory) const Q_DECL_OVERRIDE;
-    void showErrorMessage(const QString &message, const QString &title) Q_DECL_OVERRIDE;
+    void setProgressDialogLabel(const QString &text) override;
+    bool wasCanceled() const override;
+    int mergeConfigMessageBox(const QString &configName) const override;
+    bool overwriteConfigMessageBox(const QString &configName) const override;
+    bool overwriteDirectoryMessageBox(const QString &directory) const override;
+    void showErrorMessage(const QString &message, const QString &title) override;
 
 private:
     QProgressDialog *mProgressDialog;
